lyceum package
==============

Submodules
----------

lyceum.structure module
-----------------------

.. automodule:: lyceum.structure
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lyceum
   :members:
   :undoc-members:
   :show-inheritance:
